@@ -3,21 +3,22 @@ import json, re, sys, os, inspect, gettext
 from pymongo import MongoClient
 from twisted.python.reflect import namedAny
 from twisted.python import log
+from wit import Wit
 
 class RulesEngine():
     def __init__(self, configuration):
         self.configuration = configuration
-        client = MongoClient(configuration['database']['server'], configuration['database']['port'])
+        client = MongoClient(self.configuration['database']['server'], self.configuration['database']['port'])
         self.database = client.lisa
         path = os.path.realpath(os.path.abspath(os.path.join(os.path.split(
         inspect.getfile(inspect.currentframe()))[0],os.path.normpath("lang/"))))
         self._ = translation = gettext.translation(domain='lisa', localedir=path, languages=[self.configuration['lang']]).ugettext
-
+        self.wit = Wit(self.configuration['wit_token'])
 
     def Rules(self, jsonData, lisaprotocol):
         rulescollection = self.database.rules
         intentscollection = self.database.intents
-        jsonInput = lisaprotocol.wit.message_send(unicode(jsonData['body']))
+        jsonInput = self.wit.get_message(unicode(jsonData['body']))
         jsonInput['from'], jsonInput['type'], jsonInput['zone'] = jsonData['from'], jsonData['type'], jsonData['zone']
 
         if self.configuration['debug']['debug_before_before_rule']:
